@@ -31,7 +31,7 @@ StorageConfig = collections.namedtuple(
     ['bucket_name', 'key_file', 'prefix', 'fqdn', 'host_file_separator', 'storage_provider',
      'base_path', 'max_backup_age', 'max_backup_count', 'api_profile', 'transfer_max_bandwidth',
      'concurrent_transfers', 'multi_part_upload_threshold', 'host', 'region', 'port', 'secure', 'aws_cli_path',
-     'backup_grace_period_in_days', 'use_sudo_for_restore']
+     'backup_grace_period_in_days', 'use_sudo_for_restore', 'k8s_mode']
 )
 
 CassandraConfig = collections.namedtuple(
@@ -244,6 +244,8 @@ def parse_config(args, config_file):
         # The FQDN for the local node should comply with the hostname resolving rules.
         config.set('storage', 'fqdn', hostname_resolver.resolve_fqdn())
 
+    config.set('storage', 'k8s_mode', str(kubernetes_enabled))
+
     return config
 
 
